% (2015)
% 
% Author :
% Jeremy Schmitt (jeremy.schmitt@ens-lyon.fr) 
% --> Contact author Nelly Pustelnik (nelly.pustelnik@ens-lyon.fr)
% 
% Contributors :
% Nelly Pustelnik (nelly.pustelnik@ens-lyon.fr)
% Patrick Flandrin (patrick.flandrin@ens-lyon.fr)
% Pierre Borgnat (pierre.borgnat@ens-lyon.fr)
% Laurent Condat (Laurent.Condat@gipsa-lab.grenoble-inp.fr)
% 
% This software contains some image processing algorithms whose purpose is to be
% used primarily for research.
% 
% This software is governed by the CeCILL license under French law and
% abiding by the rules of distribution of free software.  You can  use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info".
% 
% As a counterpart to the access to the source code and  rights to copy,
% modify and redistribute granted by the license, users are provided only
% with a limited warranty  and the software's author,  the holder of the
% economic rights,  and the successive licensors  have only  limited
% liability.
% 
% In this respect, the user's attention is drawn to the risks associated
% with loading,  using,  modifying and/or developing or reproducing the
% software by the user in light of its specific status of free software,
% that may mean  that it is complicated to manipulate,  and  that  also
% therefore means  that it is reserved for developers  and  experienced
% professionals having in-depth computer knowledge. Users are therefore
% encouraged to load and test the software's suitability as regards their
% requirements in conditions enabling the security of their systems and/or
% data to be ensured and,  more generally, to use and operate it in the
% same conditions as regards security.
% 
% The fact that you are presently reading this means that you have had
% knowledge of the CeCILL license and that you accept its terms.


%-------------------------------------------------------------------%
% 2D variational EMD : decomposition of an image into trend and imf % 
%                                                                   %
% For theoretical aspects please refer to :                         %
%  J. Schmitt, N. Pustelnik, P. Borgnat, P. Flandrin, and L. Condat,%
% A 2-D Prony-Huang Transform: A New Tool for 2-D Spectral Analysis,%
% IEEE Trans. Image processing,                                     %
% vol. 23, no. 12, pp. 5531--5544, Oct. 2014.                       %
%-------------------------------------------------------------------%

clear all
close all
clc

addpath( genpath('include'), '-end');

%select an example
%example = 'example1'; m = -20; M=20;
example = 'example2'; m = -20; M=20;
%example = 'example3'; m = -20; M=20;


%generate data

data = create_signal(example);
data.x0 = data.x;

%define parameters

lambda = define_parameters_emd_2D_demo(example);

%run algorithm

results = run_prox_emd_2D(data,lambda);

%plot results

%IMFs
figure(1);
subplot(1,lambda.K + 2,1);imagesc(data.x,[m,M]);axis image off; colormap(gray); 
title 'Original data'
subplot(1,lambda.K + 2,2);imagesc(results.trend,[m,M]);axis image off; colormap(gray);
title 'Trend'
for indi=1:lambda.K
    subplot(1,lambda.K+2,indi+2);imagesc(results.imf(:,:,indi),[m,M]);axis image off; colormap(gray);
    tit=['IMF ',num2str(indi)];
    title(tit)
end

%EMD convergence criterion
figure(2);
for indi=1:lambda.K
    subplot(1,lambda.K,indi);semilogy(results.crit(:,indi)); hold on;
    tit=['crit ',num2str(indi)];
    title(tit)
end
